@@ -18,11 +18,22 @@
 #ifndef CONTACTSLOADER_H
 #define CONTACTSLOADER_H
 #include <QThread>
+#ifdef Q_OS_SYMBIAN
+    #include <applications/qtcontacts.h>
+    using namespace QtMobility;
+#endif
+#ifdef Q_WS_MAEMO_5
+    #include "qtcontacts.h"
+    using namespace QtMobility;
+#endif
 
 class ContactsLoader : public QThread
 {
 public:
     void run();
+
+private:
+    bool IsContactValid(QContact* c, QString* number);
 };
 
 #endif // CONTACTSLOADER_H
