@@ -60,7 +60,7 @@ bool Settings::Save()
     settings->setValue("showpercentage", ShowPercentage);
     settings->setValue("showstandardcounters", ShowStandardCounters);
 
-    settings->setValue("smsdate", SmsDate.toString("dd/MM/yyyy"));
+    settings->setValue("smsdate", SmsDate);
     settings->setValue("smssent", SmsSent);
     settings->setValue("showlastdata", ShowLastData);
     settings->setValue("lastupdated", LastUpdated);
