@@ -1,3 +1,20 @@
+//    Vodafone 190
+//    Copyright (C) 2011 Paolo Iommarini
+//    sakya_tg@yahoo.it
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
+//    This program is distributed in the hope that it will be useful,
+//    but WITHOUT ANY WARRANTY; without even the implied warranty of
+//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//    GNU General Public License for more details.
+//
+//    You should have received a copy of the GNU General Public License
+//    along with this program; if not, write to the Free Software
+//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "vodafonewidget.h"
 
 VodafoneWidget::VodafoneWidget(QString username, QString password)
@@ -63,6 +80,7 @@ bool VodafoneWidget::IsLoggedIn()
                     m_Sims.append(node.firstChild().nodeValue());
             }
         }
+        //m_Sims.append("123345");
 
         QDomNode sim = user.firstChildElement("current-msisdn");
         if (!sim.isNull())
@@ -308,49 +326,52 @@ bool VodafoneWidget::GetDettaglioContatore(Counter* counter)
     if (GetReturnCode(doc) != "0")
         return false;
 
-    QString tempValue;
+    counter->Soglie.clear();
     QDomNode root = doc.firstChildElement("root");
-    QDomNodeList list = root.firstChildElement("SogliaItem").childNodes();
-    int found = 0;
-    for (int i=0; i<list.count(); i++){
-        QDomNode node = list.at(i);
-        if (node.nodeName() == "Soglia"){
-            tempValue = node.firstChild().nodeValue().replace(",", ".");
-            counter->Soglia = tempValue.toFloat();
-            found++;
-        }else if (node.nodeName() == "DisplayType"){
-            counter->SogliaDisplayType = node.firstChild().nodeValue().toInt();
-            found++;
-        }else if (node.nodeName() == "TrafficoUtilizzato"){
-            tempValue = node.firstChild().nodeValue().replace(",", ".");
-            counter->Utilizzato = node.firstChild().nodeValue().toFloat();
-            found++;
-        }else if (node.nodeName() == "TrafficoResiduo"){            
-            tempValue = node.firstChild().nodeValue().replace(",", ".");
-            counter->Residuo = node.firstChild().nodeValue().toFloat();
-            found++;
-        }else if (node.nodeName() == "DimensioneScatto"){
-            counter->DimensioneScatto = node.firstChild().nodeValue();
-            found++;
-        }else if (node.nodeName() == "UnitaContatore"){
-            counter->Unita = node.firstChild().nodeValue();
-            found++;
-        }else if (node.nodeName() == "UnitaScatto"){
-            tempValue = node.firstChild().nodeValue().replace(",", ".");
-            counter->Scatto = node.firstChild().nodeValue().toFloat();
-            found++;
-        }else if (node.nodeName() == "Periodo"){
-            counter->Periodo = QDate::fromString(node.firstChild().nodeValue(), "dd/MM/yyyy");
-            found++;
-        }else if (node.nodeName() == "DataUtile"){
-            counter->DataUtile = QDate::fromString(node.firstChild().nodeValue(), "dd/MM/yyyy");
-            found++;
+
+    QDomNode sogliaNode = root.firstChildElement("SogliaItem");
+    while (!sogliaNode.isNull()){
+        QDomNodeList list = sogliaNode.childNodes();
+        int found = 0;
+        SogliaItem soglia;
+        for (int i=0; i<list.count(); i++){
+            QDomNode node = list.at(i);
+            if (node.nodeName() == "Soglia"){
+                soglia.Soglia = GetCounterFloatValue(node.firstChild().nodeValue());
+                found++;
+            }else if (node.nodeName() == "DisplayType"){
+                soglia.DisplayType = node.firstChild().nodeValue().toInt();
+                found++;
+            }else if (node.nodeName() == "TrafficoUtilizzato"){
+                soglia.Utilizzato = GetCounterFloatValue(node.firstChild().nodeValue());
+                found++;
+            }else if (node.nodeName() == "TrafficoResiduo"){
+                soglia.Residuo = GetCounterFloatValue(node.firstChild().nodeValue());
+                found++;
+            }else if (node.nodeName() == "DimensioneScatto"){
+                soglia.DimensioneScatto = node.firstChild().nodeValue();
+                found++;
+            }else if (node.nodeName() == "UnitaContatore"){
+                soglia.Unita = node.firstChild().nodeValue();
+                found++;
+            }else if (node.nodeName() == "UnitaScatto"){
+                soglia.Scatto = GetCounterFloatValue(node.firstChild().nodeValue());
+                found++;
+            }else if (node.nodeName() == "Periodo"){
+                soglia.Periodo = QDate::fromString(node.firstChild().nodeValue(), "dd/MM/yyyy");
+                found++;
+            }else if (node.nodeName() == "DataUtile"){
+                soglia.DataUtile = QDate::fromString(node.firstChild().nodeValue(), "dd/MM/yyyy");
+                found++;
+            }
+
+            if (found == 9)
+                break;
         }
+        counter->Soglie.append(soglia);
 
-        if (found == 9)
-            break;
+        sogliaNode = sogliaNode.nextSiblingElement("SogliaItem");
     }
-
     return true;
 } // GetDettaglioContatore
 
@@ -607,3 +628,18 @@ bool VodafoneWidget::SetCurrentSim(QString sim)
     m_CurrentSim = sim;
     return true;
 }
+
+float VodafoneWidget::GetCounterFloatValue(QString value)
+{
+    float res;
+
+    QString tempValue = value.replace(",", ".");
+    if (tempValue.contains(":")){
+        QStringList ele = tempValue.split(":");
+        res = ele.at(0).toInt() * 60;
+        res += ele.at(1).toInt();
+    }else{
+        res = tempValue.toFloat();
+    }
+    return res;
+}
